@@ -4,9 +4,9 @@ use 5.012003;
 use strict;
 use warnings;
 use Carp;
+require Encode;
 
-
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 sub new {
@@ -39,6 +39,8 @@ sub TFIDF {
 		return undef;
 	}
 
+#	$word =~  s/[?;:!,.'"]//g;
+        $word =~ s/[?;:!,."\(\)]//g; 
 	return undef if (!defined $self->{file}->{$file});
 	return $self->TF($file,$word)*$self->IDF($word);
 }
@@ -86,23 +88,23 @@ sub _process_file {
 
         my $hash;
 	return undef if (!-r $file);
-        open(IF,$file) || die $file," ",$!;
-
-        while (<IF>) {
+	open my $handle, '<:encoding(UTF-8)', $file || die $file," ",$!;
+        while (<$handle>) {
                 chop;
                 my $line = lc($_);
                 my @words = split(/\s+/,$line);
                 foreach my $el (@words) {
-                        $el =~ s/[?;:!,.'"]//g; 
-                        if (defined $hash->{$el}) {
-                                $hash->{$el}++;
+                        $el =~ s/[?;:!,."\(\)]//g; 
+			my $word = Encode::encode("utf8",$el);
+                        if (defined $hash->{$word}) {
+                                $hash->{$word}++;
                         }
                         else {
-                                $hash->{$el} = 1;
+                                $hash->{$word} = 1;
                         }
                 }
         }
-	close(IF);
+	close($handle);
 	
 	$self->{file}->{$file} = $hash;
 
